
From: Max Asbock <masbock@us.ibm.com>

This patch makes serial line registration in the ibmasm service processor
driver depend on CONFIG_SERIAL_8250.  Previously the driver wouldn't
compile when serial driver support wasn't enabled.


---

 25-akpm/drivers/misc/Kconfig         |    4 +++-
 25-akpm/drivers/misc/ibmasm/Makefile |    8 +++++---
 25-akpm/drivers/misc/ibmasm/ibmasm.h |    5 +++++
 3 files changed, 13 insertions(+), 4 deletions(-)

diff -puN drivers/misc/ibmasm/ibmasm.h~ibmasm-dependency-fix drivers/misc/ibmasm/ibmasm.h
--- 25/drivers/misc/ibmasm/ibmasm.h~ibmasm-dependency-fix	2004-04-06 21:11:10.033167384 -0700
+++ 25-akpm/drivers/misc/ibmasm/ibmasm.h	2004-04-06 21:11:10.040166320 -0700
@@ -220,5 +220,10 @@ extern void ibmasmfs_unregister(void);
 extern void ibmasmfs_add_sp(struct service_processor *sp);
 
 /* uart */
+#ifdef CONFIG_SERIAL_8250
 extern void ibmasm_register_uart(struct service_processor *sp);
 extern void ibmasm_unregister_uart(struct service_processor *sp);
+#else
+#define ibmasm_register_uart(sp)	do { } while(0)
+#define ibmasm_unregister_uart(sp)	do { } while(0)
+#endif
diff -puN drivers/misc/ibmasm/Makefile~ibmasm-dependency-fix drivers/misc/ibmasm/Makefile
--- 25/drivers/misc/ibmasm/Makefile~ibmasm-dependency-fix	2004-04-06 21:11:10.034167232 -0700
+++ 25-akpm/drivers/misc/ibmasm/Makefile	2004-04-06 21:11:10.040166320 -0700
@@ -1,7 +1,7 @@
 
 obj-$(CONFIG_IBM_ASM) := ibmasm.o
 
-ibmasm-objs :=	module.o      \
+ibmasm-y :=	module.o      \
 		ibmasmfs.o    \
 		event.o       \
 		command.o     \
@@ -9,5 +9,7 @@ ibmasm-objs :=	module.o      \
 		heartbeat.o   \
 		r_heartbeat.o \
 		dot_command.o \
-		lowlevel.o    \
-		uart.o
+		lowlevel.o
+
+ibmasm-$(CONFIG_SERIAL_8250) += uart.o
+
diff -puN drivers/misc/Kconfig~ibmasm-dependency-fix drivers/misc/Kconfig
--- 25/drivers/misc/Kconfig~ibmasm-dependency-fix	2004-04-06 21:11:10.035167080 -0700
+++ 25-akpm/drivers/misc/Kconfig	2004-04-06 21:11:10.041166168 -0700
@@ -16,7 +16,9 @@ config IBM_ASM
 	  processor. The driver is meant to be used in conjunction with
 	  a user space API.
 	  The ibmasm driver also enables the OS to use the UART on the
-          service processor board as a regular serial port.
+	  service processor board as a regular serial port. To make use of
+	  this feature serial driver support (CONFIG_SERIAL_8250) must be
+	  enabled.
 	  
 
 	  If unsure, say N.

_
